<?php
/*
Plugin Name: Microsoft Ads Conversion Tracking
Plugin URI: https://toastedweb.gr/
Description: Track WooCommerce conversions with Microsoft Ads
Version: 1.0
Author: Toastedweb
Author URI: https://toastedweb.gr/
*/

// Add settings page to WordPress admin
add_action('admin_menu', 'microsoft_ads_conversion_tracking_add_admin_page');
function microsoft_ads_conversion_tracking_add_admin_page() {
	add_options_page('Microsoft Ads Conversion Tracking Settings', 'Microsoft Ads Tracking', 'manage_options', 'microsoft-ads-tracking', 'microsoft_ads_conversion_tracking_settings_page');
}

// Add settings fields to the settings page
add_action('admin_init', 'microsoft_ads_conversion_tracking_settings');
function microsoft_ads_conversion_tracking_settings() {
	register_setting('microsoft_ads_conversion_tracking_options', 'microsoft_ads_uet_tag');
}

// Display the settings page in WordPress admin
function microsoft_ads_conversion_tracking_settings_page() {
	?>
	<div class="wrap">
		<h1>Microsoft Ads Conversion Tracking Settings</h1>
		<form method="post" action="options.php">
			<?php settings_fields('microsoft_ads_conversion_tracking_options'); ?>
			<?php do_settings_sections('microsoft-ads-tracking'); ?>
			<label for="microsoft_ads_uet_tag">UET Tag ID:</label>
			<input type="text" id="microsoft_ads_uet_tag" name="microsoft_ads_uet_tag" value="<?php echo esc_attr(get_option('microsoft_ads_uet_tag')); ?>" />
			<?php submit_button(); ?>
		</form>
	</div>
	<?php
}

// Add Microsoft Ads conversion tracking code to WooCommerce thank-you page
add_action('woocommerce_thankyou', 'microsoft_ads_conversion_tracking');
function microsoft_ads_conversion_tracking($order_id) {
	// Get order information
	$order = wc_get_order($order_id);
	$order_total = $order->get_total();
	$order_currency = $order->get_currency();
	
	// Get UET tag ID from plugin settings
	$uet_tag_id = get_option('microsoft_ads_uet_tag');
	
	// Generate conversion tracking code
	$conversion_code = "<!-- Microsoft Ads Conversion Tracking Code -->
	<script>
		window.uetq = window.uetq || [];
		window.uetq.push({
			'gv': {$order_total},
			'gc': '{$order_currency}',
			'ti': '{$order_id}',
			'ra': Math.random(),
			'uet': '{$uet_tag_id}'
		});
	</script>
	<noscript>
		<img src='https://bat.bing.com/action/0?ti={$order_id}&amp;Ver=2&amp;gc={$order_currency}&amp;gv={$order_total}&amp;ca=Purchase&amp;ut={$uet_tag_id}' height='0' width='0' style='display:none; visibility: hidden;'/>
	</noscript>
	<!-- End Microsoft Ads Conversion Tracking Code -->";
	
	// Output conversion tracking code
	echo $conversion_code;
}
